slepc-3.18.0 2022-10-01
Report Typos and Errors

# BVCopy

Copies a basis vector object into another one, W <- V.

### Synopsis

    #include "slepcbv.h"
    PetscErrorCode BVCopy(BV V,BV W)

Logically Collective on V

### Input Parameter

| V | - basis vectors context

### Output Parameter

| W | - the copy

### Note

Both V and W must be distributed in the same manner; local copies are done. Only active columns (excluding the leading ones) are copied. In the destination W, columns are overwritten starting from the leading ones. Constraints are not copied.

### See Also

BVCopyVec(), BVCopyColumn(), BVDuplicate(), BVSetActiveColumns()

### Level

beginner

### Location

src/sys/classes/bv/interface/bvbasic.c
Index of all BV routines
Table of Contents for all manual pages
Index of all manual pages